@@ -404,6 +404,12 @@
 /*1.8.1-t1 disable select auto dial*/
 /*1.9 add count no connected call, disable call logs*/
 /*1.9.1 add fd limit*/
+
+/*1.9.2 add imei_imsi file*/
+        if(!$rs || $rs[0] < 113){
+                @$db->updatequery("ALTER TABLE `imei_db` ADD UNIQUE ( `imei` ) ");
+                @$db->updatequery("update `system` set `version`='113'");
+        }
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 ?>
